Date: 01 4, 2002 12:05:53 PM

# strendswith

## Purpose

Check if a string is is terminated by the given substring.

## Syntax

returnedBoolean = strendswith(wordString, suffixString)

returnedBoolean - type: bool
wordString - type: str
suffixString - type: str

## Returns

## Remarks

Unlike the function called suffix, strendswith does a simple check for terminal string.

## Example

@POST
if (!strendswith(N("$text",1),"ing"))
fail();
@RULES
_ving <- _verb @@

## See Also

strcontains, strcontainsnocase, strpiece, strsubst, suffix, String Functions